import iam = require('@aws-cdk/aws-iam');
import cdk = require('@aws-cdk/cdk');
export interface RuntimeValueProps {
    /**
     * A namespace for the runtime value.
     * It is recommended to use the name of the library/package that advertises this value.
     */
    readonly package: string;
    /**
     * The value to advertise. Can be either a primitive value or a token.
     */
    readonly value: any;
}
/**
 * Defines a value published from construction code which needs to be accessible
 * by runtime code.
 */
export declare class RuntimeValue extends cdk.Construct {
    /**
     * The recommended name of the environment variable to use to set the stack name
     * from which the runtime value is published.
     */
    static readonly ENV_NAME = "RTV_STACK_NAME";
    /**
     * IAM actions needed to read a value from an SSM parameter.
     */
    private static readonly SSM_READ_ACTIONS;
    /**
     * The value to assign to the `RTV_STACK_NAME` environment variable.
     */
    readonly envValue: string;
    /**
     * The name of the runtime parameter.
     */
    readonly parameterName: string;
    /**
     * The ARN fo the SSM parameter used for this runtime value.
     */
    readonly parameterArn: string;
    constructor(scope: cdk.Construct, id: string, props: RuntimeValueProps);
    /**
     * Grants a principal read permissions on this runtime value.
     * @param grantee The principal (e.g. Role, User, Group)
     */
    grantRead(grantee: iam.IGrantable): iam.Grant;
}
